#include <LiquidCrystal_I2C.h>  // Initialize LCD with I2C address 0x27 and size 16x2
LiquidCrystal_I2C lcd(0x27, 16, 2);  // Button pins
#define button1 2
#define button2 3
#define button3 4
#define button4 5
#define button5 6
#define button6 7
#define button7 8  // Reset button

// LED pins
#define greenLED 9
#define redLED 10

// Vote counters
int vote1 = 0, vote2 = 0, vote3 = 0, vote4 = 0, vote5 = 0, vote6 = 0;

// Reset vote counters
void resetVotes() {
  vote1 = 0;
  vote2 = 0;
  vote3 = 0;
  vote4 = 0;
  vote5 = 0;
  vote6 = 0;
  updateLiveVotes();
}

void setup() {
  // Initialize LCD
  lcd.init();
  lcd.backlight();

  // Set up buttons as inputs
  pinMode(button1, INPUT_PULLUP);
  pinMode(button2, INPUT_PULLUP);
  pinMode(button3, INPUT_PULLUP);
  pinMode(button4, INPUT_PULLUP);
  pinMode(button5, INPUT_PULLUP);
  pinMode(button6, INPUT_PULLUP);
  pinMode(button7, INPUT_PULLUP);  // Reset button

  // Set up LEDs as outputs
  pinMode(greenLED, OUTPUT);
  pinMode(redLED, OUTPUT);

  // Welcome message on LCD
  lcd.setCursor(0, 0);
  lcd.print("Voting System");
  lcd.setCursor(0, 1);
  lcd.print("Ready to Vote");
  delay(3000);
  lcd.clear();

  // Display initial vote counts
  updateLiveVotes();
}

void loop() {
  // Check buttons for voting
  if (digitalRead(button1) == LOW) {
    vote1++;
    confirmVote();
    updateLiveVotes();
    while (digitalRead(button1) == LOW); // Wait until button is released
  }

  if (digitalRead(button2) == LOW) {
    vote2++;
    confirmVote();
    updateLiveVotes();
    while (digitalRead(button2) == LOW);
  }

  if (digitalRead(button3) == LOW) {
    vote3++;
    confirmVote();
    updateLiveVotes();
    while (digitalRead(button3) == LOW);
  }

  if (digitalRead(button4) == LOW) {
    vote4++;
    confirmVote();
    updateLiveVotes();
    while (digitalRead(button4) == LOW);
  }

  if (digitalRead(button5) == LOW) {
    vote5++;
    confirmVote();
    updateLiveVotes();
    while (digitalRead(button5) == LOW);
  }

  if (digitalRead(button6) == LOW) {
    vote6++;
    confirmVote();
    updateLiveVotes();
    while (digitalRead(button6) == LOW);
  }

  // Check reset button
  if (digitalRead(button7) == LOW) {
    resetVotes();  // Reset all votes
    while (digitalRead(button7) == LOW);  // Wait until button is released
  }
}

void updateLiveVotes() {
  lcd.clear();
  lcd.setCursor(0, 0);
  lcd.print("A:"); lcd.print(vote1);
  lcd.print(" B:"); lcd.print(vote2);
  lcd.setCursor(0, 1);
  lcd.print("C:"); lcd.print(vote3);
  lcd.print(" D:"); lcd.print(vote4);
  lcd.setCursor(0, 2);
  lcd.print("E:"); lcd.print(vote5);
  lcd.print(" F:"); lcd.print(vote6);
}

void confirmVote() {
  digitalWrite(greenLED, HIGH); // Turn on Green LED
  delay(500);
  digitalWrite(greenLED, LOW);
  delay(500);
  delay(4000); // Wait 4 seconds before accepting the next vote
}
